/*
******************************************************************************

   LibBuf dynamic library management
  
   Copyright (c) Wed Aug 29 2001 by: 
	Brian S. Julin		bri@tull.umassp.edu
        Christoph Egger         Christoph_Egger@t-online.de
   
This software may be redistributed under the terms of the GNU Library
(a.k.a. "Lesser") Public License -- see the file COPYING in the parent 
directory of the source code.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.




******************************************************************************
*/

#include <ggi/internal/buf.h>

/* Generate a string representing the pixelformat e.g. r5g6b5 */
void BUF_getapi_fstr (ggi_visual *vis, char* str, int flags)
{

	if (flags & BUF_GETAPI_GIVE_PIXFMT) {
		char alpha_or_pad, *ptr;
		ggi_pixelformat *pixfmt;
		int idx;

		pixfmt = LIBGGI_PIXFMT(vis);
		alpha_or_pad = (flags & BUF_GETAPI_ALPHA_USED) ? 'a' : 'p';
		idx = pixfmt->depth - 1;
		if (idx > 31) return; /* paranoia never hurts. */
		ptr = str;
		*ptr = '-';
		ptr++;

		while (1) {
			switch(pixfmt->bitmeaning[idx] & 0x00ffff00) {
			      case GGI_BM_TYPE_COLOR | GGI_BM_SUB_RED:
				*(ptr++) = 'r';
				break;
			      case GGI_BM_TYPE_COLOR | GGI_BM_SUB_GREEN:
				*(ptr++) = 'g';
				break;
			      case GGI_BM_TYPE_COLOR | GGI_BM_SUB_BLUE:
				*(ptr++) = 'b';
				break;
			      case GGI_BM_TYPE_ATTRIB | GGI_BM_SUB_ALPHA:
				*(ptr++) = alpha_or_pad;
				break;
			      default:
				*(ptr++) = 'p';
				break;
			}
			while ((pixfmt->bitmeaning[idx] & 0x00ffff00) ==
			       (pixfmt->bitmeaning[idx - 1] & 0x00ffff00)) {
			  if (idx == 0) break;
			  idx--;
			}
			ptr += sprintf(ptr, "%d", 
				       256-(pixfmt->bitmeaning[idx] & 0xff)
				       );
			idx--;
			if (idx < 0) break;

		}	/* while */
		*ptr = '\0';
	}	/* if */
	else sprintf(str, "-%d", GT_SIZE(LIBGGI_GT(vis)));
}	/* BUF_getapi_fstr */

